@@ -151,7 +151,6 @@ use std::collections::{HashMap, HashSet, VecDeque};
 use std::fmt;
 use std::future::Future;
 use std::pin::Pin;
-use std::sync::Arc;
 use std::task::{Context, Poll};
 
 mod domain;
@@ -270,7 +269,7 @@ pub struct Crawler<T: Scraper> {
     in_progress_crawl_requests: Vec<CrawlRequest<T::State>>,
     queued_results: VecDeque<CrawlResult<T>>,
     /// The client that issues all the requests
-    client: Arc<reqwest::Client>,
+    client: reqwest::Client,
     /// used to track the depth of submitted requests
     current_depth: usize,
     /// Either a list that only allows a set of domains or disallows a set of
@@ -290,14 +289,12 @@ pub struct Crawler<T: Scraper> {
 impl<T: Scraper> Crawler<T> {
     /// Create a new crawler following the config
     pub fn new(config: CrawlerConfig) -> Self {
-        let client = config
-            .client
-            .unwrap_or_else(|| Arc::new(Default::default()));
+        let client = config.client.unwrap_or_default();
 
         let list = if config.allowed_domains.is_empty() {
             let block_list = BlockList::new(
                 config.disallowed_domains,
-                Arc::clone(&client),
+                client.clone(),
                 config.respect_robots_txt,
                 config.skip_non_successful_responses,
                 config.max_depth.unwrap_or(usize::MAX),
@@ -316,7 +313,7 @@ impl<T: Scraper> Crawler<T> {
                 let allow = AllowListConfig {
                     delay,
                     respect_robots_txt: config.respect_robots_txt,
-                    client: Arc::clone(&client),
+                    client: client.clone(),
                     skip_non_successful_responses: config.skip_non_successful_responses,
                     max_depth: config.max_depth.unwrap_or(usize::MAX),
                     max_requests,
@@ -367,11 +364,11 @@ where
     /// the scraper again
     pub fn crawl<TCrawlFunction, TCrawlFuture>(&mut self, fun: TCrawlFunction)
     where
-        TCrawlFunction: FnOnce(Arc<reqwest::Client>) -> TCrawlFuture,
+        TCrawlFunction: FnOnce(&reqwest::Client) -> TCrawlFuture,
         TCrawlFuture: Future<Output = Result<(reqwest::Response, Option<T::State>)>> + 'static,
     {
         let depth = self.current_depth + 1;
-        let fut = (fun)(Arc::clone(&self.client));
+        let fut = (fun)(&self.client);
         let fut = Box::pin(async move {
             let (mut resp, state) = fut.await?;
             let (status, url, headers) = response_info(&mut resp);
@@ -397,10 +394,10 @@ where
     /// returned once finished.
     pub fn complete<TCrawlFunction, TCrawlFuture>(&mut self, fun: TCrawlFunction)
     where
-        TCrawlFunction: FnOnce(Arc<reqwest::Client>) -> TCrawlFuture,
+        TCrawlFunction: FnOnce(&reqwest::Client) -> TCrawlFuture,
         TCrawlFuture: Future<Output = Result<Option<T::Output>>> + 'static,
     {
-        let fut = (fun)(Arc::clone(&self.client));
+        let fut = (fun)(&self.client);
         self.in_progress_complete_requests.push(Box::pin(fut))
     }
 
@@ -438,7 +435,7 @@ where
 
     /// The client that performs all request
     pub fn client(&self) -> &reqwest::Client {
-        self.client.as_ref()
+        &self.client
     }
 
     /// advance all requests
@@ -573,7 +570,7 @@ pub struct CrawlerConfig {
     // /// Delay a request
     // request_delay: Option<RequestDelay>,
     /// The client that will be used to send the requests
-    client: Option<Arc<reqwest::Client>>,
+    client: Option<reqwest::Client>,
 }
 
 impl Default for CrawlerConfig {
@@ -609,12 +606,18 @@ impl CrawlerConfig {
     }
 
     pub fn set_client(mut self, client: reqwest::Client) -> Self {
-        self.client = Some(Arc::new(client));
+        self.client = Some(client);
         self
     }
 
-    pub fn with_shared_client(mut self, client: Arc<reqwest::Client>) -> Self {
-        self.client = Some(client);
+    /// *NOTE* [`reqwest::Client`] already uses Arc under the hood, so
+    /// it's preferable to just `clone` it and pass via [`Self::set_client`]
+    #[deprecated(
+        since = "0.2.0",
+        note = "You do not have to wrap the Client it in a `Arc` to reuse it, because it already uses an `Arc` internally. Users should use `set_client` instead."
+    )]
+    pub fn with_shared_client(mut self, client: std::sync::Arc<reqwest::Client>) -> Self {
+        self.client = Some(client.as_ref().clone());
         self
     }
 
